@@ -267,7 +267,7 @@ def run_tests(sandbox_dir, packages, options):
 
         d = dict(number_tests=0,
                  number_failures=0,
-                 tests_ok=0)
+                 tests_ok=False)
 
         status_line = dispa = ''
 
