@@ -153,12 +153,18 @@ def db(results, options, tests_failed):
 
     for k in sorted(results.keys()):
         url = '%s/%s' % (options.base_url, results[k]['logfile']) 
+        logdata=open(results[k]['logfilepath']).read()
+        try:
+            logdata = unicode(logdata, 'iso-8859-15', 'ignore').encode('ascii', 'replace')
+        except UnicodeError:
+            logdata = unicode(logdata, 'utf-8', 'ignore').encode('ascii', 'replace')
+
         R.result.append(Result(module=unicode(k),
                         tests_passed=results[k]['number_tests'] - results[k]['number_failures'],
                         tests_total=results[k]['number_tests'],
                         tests_ok=results[k]['tests_ok'],
                         logfile=unicode(url),
-                        logdata=open(results[k]['logfilepath']).read(),
+                        logdata=logdata,
                         ))
 
     TR.run.append(R)
